@@ -2,23 +2,13 @@ package Sereal;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION= '4.017_001';
-our $XS_VERSION= $VERSION; $VERSION= eval $VERSION;
-use Sereal::Encoder 4.017_001 qw(
-    encode_sereal
-    sereal_encode_with_object
-    SRL_UNCOMPRESSED
-    SRL_SNAPPY
-    SRL_ZLIB
-    SRL_ZSTD
-);
-use Sereal::Decoder 4.017_001 qw(
-    decode_sereal
-    looks_like_sereal
-    decode_sereal_with_header_data
+our $VERSION = '4.002';
+our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
+use Sereal::Encoder 4.002 qw(encode_sereal sereal_encode_with_object);
+use Sereal::Decoder 4.002 qw(
+    decode_sereal looks_like_sereal decode_sereal_with_header_data
     scalar_looks_like_sereal
-    sereal_decode_with_object
-    sereal_decode_with_header_with_object
+    sereal_decode_with_object sereal_decode_with_header_with_object
     sereal_decode_only_header_with_object
     sereal_decode_only_header_with_offset_with_object
     sereal_decode_with_header_and_offset_with_object
@@ -26,79 +16,58 @@ use Sereal::Decoder 4.017_001 qw(
 );
 
 use Exporter 'import';
-our @EXPORT_OK= qw(
-    get_sereal_decoder
-    get_sereal_encoder
-    clear_sereal_object_cache
+our @EXPORT_OK = qw(
+  get_sereal_decoder
+  get_sereal_encoder
+  clear_sereal_object_cache
 
-    encode_sereal
-    decode_sereal
-
-    read_sereal
-    read_sereal_file
-    write_sereal
-    write_sereal_file
-
-    looks_like_sereal
-    scalar_looks_like_sereal
-
-    sereal_encode_with_object
-    sereal_decode_with_object
-    decode_sereal_with_header_data
-
-    sereal_decode_with_header_with_object
-    sereal_decode_only_header_with_object
-    sereal_decode_only_header_with_offset_with_object
-    sereal_decode_with_header_and_offset_with_object
-    sereal_decode_with_offset_with_object
-
-    SRL_UNCOMPRESSED
-    SRL_SNAPPY
-    SRL_ZLIB
-    SRL_ZSTD
+  encode_sereal decode_sereal
+  write_sereal read_sereal
+  looks_like_sereal
+  sereal_encode_with_object
+  sereal_decode_with_object
+  decode_sereal_with_header_data
+  scalar_looks_like_sereal
+  sereal_decode_with_header_with_object
+  sereal_decode_only_header_with_object
+  sereal_decode_only_header_with_offset_with_object
+  sereal_decode_with_header_and_offset_with_object
+  sereal_decode_with_offset_with_object
 );
-our %EXPORT_TAGS= ( all => \@EXPORT_OK );
-
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
-our @EXPORT= ( ( caller() )[1] eq '-e' ? @EXPORT_OK : () );
+our @EXPORT = ((caller())[1] eq '-e' ? @EXPORT_OK : ());
 
 our %ENCODERS;
 our %DECODERS;
 
-sub _key {
-    join "\t", map { $_ => $_[0]->{$_} } sort keys %{ $_[0] };
-}
+sub _key { join "\t", map { $_ => $_[0]->{$_} } sort keys %{$_[0]} }
 
 sub clear_sereal_object_cache {
-    my $count= keys(%DECODERS) + keys(%ENCODERS);
     %ENCODERS= ();
     %DECODERS= ();
-    return $count;
 }
 
 sub get_sereal_encoder {
     my ($opts)= @_;
-    return $ENCODERS{ _key($opts) } ||= Sereal::Encoder->new($opts);
+    return $ENCODERS{_key($opts)} ||= Sereal::Encoder->new($opts);
 }
 
 sub get_sereal_decoder {
     my ($opts)= @_;
-    return $DECODERS{ _key($opts) } ||= Sereal::Decoder->new($opts);
+    return $DECODERS{_key($opts)} ||= Sereal::Decoder->new($opts);
 }
 
-sub write_sereal_file {
-    my ( $file, $struct, $append, $opts )= @_;
-    get_sereal_encoder($opts)->encode_to_file( $file, $_[1], $append );
+sub write_sereal {
+    my ($file, $struct, $append, $opts)= @_;
+    get_sereal_encoder($opts)->write_to_file($file, $_[1], $append);
 }
 
-sub read_sereal_file {
-    my ( $file, $opts )= @_;
-    get_sereal_decoder($opts)->decode_from_file( $file, @_ > 2 ? $_[2] : () );
+sub read_sereal {
+    my ($file, $opts)= @_;
+    get_sereal_decoder($opts)->read_from_file($file,$_[2]);
 }
 
-*read_sereal= *read_sereal= *read_sereal_file;
-*write_sereal= *write_sereal= *write_sereal_file;
-
 1;
 
 __END__
@@ -111,41 +80,14 @@ Sereal - Fast, compact, powerful binary (de-)serialization
 
 =head1 SYNOPSIS
 
-    use Sereal qw(
-        get_sereal_decoder
-        get_sereal_encoder
-        clear_sereal_object_cache
-
-        encode_sereal
-        decode_sereal
-
-        read_sereal
-        read_sereal_file
-        write_sereal
-        write_sereal_file
-
-        looks_like_sereal
-        scalar_looks_like_sereal
-
-        sereal_encode_with_object
-        sereal_decode_with_object
-        decode_sereal_with_header_data
-
-        sereal_decode_with_header_with_object
-        sereal_decode_only_header_with_object
-        sereal_decode_only_header_with_offset_with_object
-        sereal_decode_with_header_and_offset_with_object
-        sereal_decode_with_offset_with_object
-
-        SRL_UNCOMPRESSED
-        SRL_SNAPPY
-        SRL_ZLIB
-        SRL_ZSTD
-    );
-    # Note: For performance reasons, you should prefer the OO interface,
-    #       or sereal_(en|de)code_with_object over the stateless
-    #       encode_sereal/decode_sereal functions.
-    #       See the Sereal::Performance documentation for details.
+  use Sereal qw(encode_sereal decode_sereal
+                sereal_encode_with_object
+                sereal_decode_with_object
+                looks_like_sereal);
+  # Note: For performance reasons, you should prefer the OO interface,
+  #       or sereal_(en|de)code_with_object over the stateless
+  #       encode_sereal/decode_sereal functions.
+  #       See the Sereal::Performance documentation for details.
 
 =head1 DESCRIPTION
 
@@ -200,26 +142,13 @@ to this function.
 Returns a Sereal::Decoder with the given options. This encoder will be shared by other calls
 to this function.
 
-=head2 clear_sereal_object_cache
-
-Clears cache of objects created via get_sereal_encoder() and get_sereal_decoder(). Returns
-the number of objects that were removed from the cache (the sum of both types).
-
-=head2 write_sereal_file($FILENAME,$STRUCT,$APPEND,$OPTS)
-
-Write a sereal packet to $FILENAME. See Sereal::Encoder::encode_to_file().
-
 =head2 write_sereal($FILENAME,$STRUCT,$APPEND,$OPTS)
 
-alias for write_sereal_file()
+Write a sereal packet to $FILENAME. See Sereal::Encoder::write_to_file().
 
-=head2 read_sereal_file($FILENAME,$OPTS,$ROOT)
+=head2 read_sereal($FILENAME,$OPTS)
 
-Read a sereal packet from a file. See Sereal::Decoder::decode_from_file().
-
-=head2 read_sereal($FILENAME,$OPTS,$ROOT)
-
-alias for read_sereal_file()
+Read a sereal packet from a file. See Sereal::Decoder::read_from_file().
 
 =head1 BUGS, CONTACT AND SUPPORT
 
